encode_batch_with_identifier

Function encode_batch_with_identifier 

pub fn encode_batch_with_identifier<'a, T, D, I>(
    type_name: &'static str,
    metadata: &HashMap<String, String>,
    data: D,
    fields: &[JsonFieldSpec],
    identifiers: impl IntoIterator<Item = I>,
) -> Result<RecordBatch, ArrowError>
where T: Serialize + 'a, D: IntoIterator<Item = &'a T>, D::IntoIter: ExactSizeIterator, I: Display,
Encodes typed records with the catalog row identifier column.

Errors

Returns an error if the number of identifiers differs from the number of data rows or if any field cannot be encoded into the requested Arrow column type.