pub fn encode_batch_with_identifier<'a, T, D, I>(
type_name: &'static str,
metadata: &HashMap<String, String>,
data: D,
fields: &[JsonFieldSpec],
identifiers: impl IntoIterator<Item = I>,
) -> Result<RecordBatch, ArrowError>Expand description
Encodes typed records with the catalog row identifier column.
Errors
Returns an error if the number of identifiers differs from the number of data rows or if any field cannot be encoded into the requested Arrow column type.